
# THIS FILE IS GENERATED FROM tyssue SETUP.PY
#
short_version = '0.8.0'
full_version = '0.8.0'
git_revision = '75140db9a5c04a738b14f95da6c0f3cacb549efe'
release = True
if release:
    version = full_version
else:
    version = short_version
